# Whitening subpackage developing notes

These notes are used for keeping track of ToDos and porting information.

## Porting status
- Rotating and rescaling has been implemented, but nonlinear warping has not.

## Matlab references
- Corresponding MATLAB functions:
    - [unscent_warp.m](https://github.com/acerbilab/vbmc/blob/master/utils/unscent_warp.m)
    - [warp_input_vbmc.m](https://github.com/acerbilab/vbmc/blob/master/misc/warp_input_vbmc.m)
    - [warp_gpandvp_vbmc.m](https://github.com/acerbilab/vbmc/blob/master/misc/warp_gpandvp_vbmc.m)
